@@ -25,6 +25,7 @@ from audoma_api.permissions import (
     ViewPermission,
 )
 from audoma_api.serializers import (
+    CarDetailModelSerializer,
     CarModelSerializer,
     ExampleFileModelSerializer,
     ExampleModelCreateSerializer,
@@ -196,6 +197,14 @@ class CarViewSet(
     search_fields = ["=manufacturer", "name"]
 
 
+class CarDetailViewset(
+    mixins.UpdateModelMixin, mixins.CreateModelMixin, viewsets.GenericViewSet
+):
+    queryset = Car.objects.all()
+    serializer_class = CarDetailModelSerializer
+    lookup_url_kwarg = "id"
+
+
 class MutuallyExclusiveViewSet(
     mixins.ActionModelMixin,
     mixins.CreateModelMixin,
@@ -268,6 +277,9 @@ class ExampleModelPermissionLessViewSet(
         return ExampleModel.objects.none()
 
     def get_object(self):
+        if self.action != "example_update_action":
+            return None
+
         return ExampleModel(
             char_field="TESTChar",
             phone_number="+18888888822",
